/**
 * 判断是否为无声,
 * 方法 1：检查 Buffer 是否全 0（适用于原始 PCM 数据）
 * @param chunk
 * @returns
 */
export const isSilentNoLength = (chunk: Buffer) => {
  const isSilent = Buffer.compare(chunk, Buffer.alloc(chunk.length)) === 0;
  return isSilent;
};

/**
 * 判断是否为无声, 统计振幅（更通用）
 * 方法 2：检查每个样本是否低于阈值
 * @param chunk
 * @param threshold
 * @returns
 */
export function isChunkSilent(chunk: Buffer, threshold = 0.01) {
  const floats = new Float32Array(chunk.buffer);
  for (let i = 0; i < floats.length; i++) {
    if (Math.abs(floats[i]) > threshold) {
      return false; // 发现非静音样本
    }
  }
  return true; // 所有样本均低于阈值
}
